#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-hs
version:              0.12.1
visibility:           public
id:                   arch-hs-0.12.1-38a0YCbe9256dAYomhnl0x
key:                  arch-hs-0.12.1-38a0YCbe9256dAYomhnl0x
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  b1df1b09f7852773e28c9bde2a45e16c
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.ExtraDB Distribution.ArchHs.FilesDB
    Distribution.ArchHs.Hackage Distribution.ArchHs.Internal.Prelude
    Distribution.ArchHs.Local Distribution.ArchHs.Name
    Distribution.ArchHs.Options Distribution.ArchHs.PP
    Distribution.ArchHs.PkgBuild Distribution.ArchHs.PkgDesc
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.12.1-38a0YCbe9256dAYomhnl0x
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1/include
depends:
    Cabal-3.10.3.0 Diff-0.5-fNSHrsymP36dtk0YqFhZ1
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    algebraic-graphs-0.7-L9d8olshohM8GKjzkG7NG4
    arch-web-0.3.2-GE6oovMBzSK24bCgKo4PAD base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-8P16HBmakUKG1It6ArZYEY
    conduit-extra-1.3.8-LOPp6e09V66LxLJXrnknNu containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    hackage-db-2.1.3-AqEM0cytLbA6sQUf6F4UBd
    http-client-0.7.19-A1qGvj2MlivKXlcAABR34l
    http-client-tls-0.3.6.4-63NdgoH5NGbC0F7SbjBwuZ
    megaparsec-9.7.0-HwFCj8AZlAe6hd0TjBRiui
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-Kiwz6ZYAlfY2CJ1USHbUAH
    neat-interpolation-0.5.1.4-2Zs5AKIoUDG2nLbCzwGnAM
    optparse-simple-0.1.1.4-57WgTdkRYLXCXdFuhIBmfq
    polysemy-1.9.2.0-Hb6AegM7jPCCPdQs3aFiHg
    prettyprinter-1.7.1-DrhJgh2zvVyDSlphpqlv9X
    prettyprinter-ansi-terminal-1.1.3-4NBKkPa3YgEBUirxYRzZyb
    servant-client-0.20.3.0-2DMQBiPaKfUFn2Zved9hRx
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    tar-conduit-0.4.1-5qTZVOq72Ah8zARcmjdff8 template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

